{% extends "andablog/base.html" %}
{% load andablog_tags %}

{% block andablog_meta %}
    <meta name="description" content="{{ entry.title }}">
    <meta name="author" content="{{ entry.author.get_short_name }}">
{% endblock %}

{% block andablog_page_title %}
    {{ entry.title }}
{% endblock %}

{% block andablog_content %}
    <div class="blog-post">
        <h2 class="blog-post-title">{{ entry.title }}{% if not entry.is_published %} <span class="label label-default">Draft</span>{% endif %}</h2>
        <p class="blog-post-meta">{{ entry.published_timestamp|date:"DATE_FORMAT" }}{% if entry.author %} by {{ entry.author|authordisplay }}{% endif %}</p>
        <p>
            {{ entry.content }}
        </p>

        {% include "andablog/comments_snippet.html" with comment_object=entry %}
    </div>
{% endblock %}
