{% comment %}
This template must be overriden to implement listing comments and displaying a comment box.

You will recieve a context object called comment_object which is the object being commented on.
{% endcomment %}
